---
icon: lucide/file-code
---

# API Reference


## Tracing

::: raytrax.trace
    options:
      heading_level: 3
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true


## Input Types

::: raytrax.equilibrium.interpolate.MagneticConfiguration
    options:
      heading_level: 3
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

::: raytrax.types.Beam
    options:
      heading_level: 3
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

::: raytrax.types.RadialProfiles
    options:
      heading_level: 3
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true


## Output Types

::: raytrax.types.TraceResult
    options:
      heading_level: 3
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

::: raytrax.types.BeamProfile
    options:
      heading_level: 3
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

::: raytrax.types.RadialProfile
    options:
      heading_level: 3
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true


## Physics

::: raytrax.physics.hamiltonian.hamiltonian
    options:
      heading_level: 3
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

::: raytrax.physics.hamiltonian.hamiltonian_gradients
    options:
      heading_level: 3
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

::: raytrax.physics.absorption.absorption_coefficient
    options:
      heading_level: 3
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true


## Plotting

### 1D

::: raytrax.plot.plot1d.plot_linear_power_density
    options:
      heading_level: 4
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

::: raytrax.plot.plot1d.plot_radial_power_density
    options:
      heading_level: 4
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

::: raytrax.plot.plot1d.plot_radial_electron_density
    options:
      heading_level: 4
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

::: raytrax.plot.plot1d.plot_radial_electron_temperature
    options:
      heading_level: 4
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

### 2D

::: raytrax.plot.plot2d.plot_beamtrace_rz
    options:
      heading_level: 4
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

::: raytrax.plot.plot2d.plot_electron_density_rz
    options:
      heading_level: 4
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

::: raytrax.plot.plot2d.plot_magnetic_field_rz
    options:
      heading_level: 4
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

::: raytrax.plot.plot2d.plot_effective_radius_rz
    options:
      heading_level: 4
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

### 3D

::: raytrax.plot.plot3d.plot_beam_profile_3d
    options:
      heading_level: 4
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

::: raytrax.plot.plot3d.plot_flux_surface_3d
    options:
      heading_level: 4
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true

::: raytrax.plot.plot3d.plot_b_surface_3d
    options:
      heading_level: 4
      show_source: false
      show_root_members_full_path: true
      show_root_heading: true
      show_signature_annotations: true
